grib2io.tables.section4 API documentation

# grib2io.tables.section4

View Source

       1table_4_1_0 = {
       2'0':'Temperature',
       3'1':'Moisture',
       4'2':'Momentum',
       5'3':'Mass',
       6'4':'Short-wave radiation',
       7'5':'Long-wave radiation',
       8'6':'Cloud',
       9'7':'Thermodynamic Stability indicies',
      10'8':'Kinematic Stability indicies',
      11'9':'Temperature Probabilities*',
      12'10':'Moisture Probabilities*',
      13'11':'Momentum Probabilities*',
      14'12':'Mass Probabilities*',
      15'13':'Aerosols',
      16'14':'Trace gases',
      17'15':'Radar',
      18'16':'Forecast Radar Imagery',
      19'17':'Electrodynamics',
      20'18':'Nuclear/radiology',
      21'19':'Physical atmospheric properties',
      22'20':'Atmospheric chemical Constituents',
      23'21-189':'Reserved',
      24'190':'CCITT IA5 string',
      25'191':'Miscellaneous',
      26'192-254':'Reserved for Local Use',
      27'192':'Covariance',
      28'255':'Missing',
      29}
      30
      31table_4_1_1 = {
      32'0':'Hydrology basic products',
      33'1':'Hydrology probabilities',
      34'2':'Inland water and sediment properties',
      35'3-191':'Reserved',
      36'192-254':'Reserved for Local Use',
      37'255':'Missing',
      38}
      39
      40table_4_1_2 = {
      41'0':'Vegetation/Biomass',
      42'1':'Agricultural/Aquacultural Special Products',
      43'2':'Transportation-related Products',
      44'3':'Soil Products',
      45'4':'Fire Weather Products',
      46'5':'Land Surface Products',
      47'6-191':'Reserved',
      48'192-254':'Reserved for Local Use',
      49'255':'Missing',
      50}
      51
      52table_4_1_3 = {
      53'0':'Image format products',
      54'1':'Quantitative products',
      55'2':'Cloud Properties',
      56'3':'Flight Rules Conditions',
      57'4':'Volcanic Ash',
      58'5':'Sea-surface Temperature',
      59'6':'Solar Radiation',
      60'7-191':'Reserved',
      61'192-254':'Reserved for Local Use',
      62'192':'Forecast Satellite Imagery',
      63'255':'Missing',
      64}
      65
      66table_4_1_4 = {
      67'0':'Temperature',
      68'1':'Momentum',
      69'2':'Charged Particle Mass and Number',
      70'3':'Electric and Magnetic Fields',
      71'4':'Energetic Particles',
      72'5':'Waves',
      73'6':'Solar Electromagnetic Emissions',
      74'7':'Terrestrial Electromagnetic Emissions',
      75'8':'Imagery',
      76'9':'Ion-Neutral Coupling',
      77'10':'Space Weather Indices',
      78'11-191':'Reserved',
      79'192-254':'Reserved for Local Use',
      80'255':'Missing',
      81}
      82
      83table_4_1_10 = {
      84'0':'Waves',
      85'1':'Currents',
      86'2':'Ice',
      87'3':'Surface Properties',
      88'4':'Sub-surface Properties',
      89'5-190':'Reserved',
      90'191':'Miscellaneous',
      91'192-254':'Reserved for Local Use',
      92'255':'Missing',
      93}
      94
      95table_4_1_20 = {
      96'0':'Health Indicators',
      97'1':'Epidemiology',
      98'2':'Socioeconomic indicators',
      99'3-191':'Reserved',
     100'192-254':'Reserved for Local Use',
     101'255':'Missing',
     102}
     103
     104table_4_0 = {
     105'0':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time. (see Template 4.0)',
     106'1':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time. (see Template 4.1)',
     107'2':'Derived forecasts based on all ensemble members at a horizontal level or in a horizontal layer at a point in time. (see Template 4.2)',
     108'3':'Derived forecasts based on a cluster of ensemble members over a rectangular area at a horizontal level or in a horizontal layer at a point in time. (see Template 4.3)',
     109'4':'Derived forecasts based on a cluster of ensemble members over a circular area at a horizontal level or in a horizontal layer at a point in time. (see Template 4.4)',
     110'5':'Probability forecasts at a horizontal level or in a horizontal layer at a point in time. (see Template 4.5)',
     111'6':'Percentile forecasts at a horizontal level or in a horizontal layer at a point in time. (see Template 4.6)',
     112'7':'Analysis or forecast error at a horizontal level or in a horizontal layer at a point in time. (see Template 4.7)',
     113'8':'Average, accumulation, extreme values or other statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval. (see Template 4.8)',
     114'9':'Probability forecasts at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval. (see Template 4.9)',
     115'10':'Percentile forecasts at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval. (see Template 4.10)',
     116'11':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval. (see Template 4.11)',
     117'12':'Derived forecasts based on all ensemble members at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval. (see Template 4.12)',
     118'13':'Derived forecasts based on a cluster of ensemble members over a rectangular area at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval. (see Template 4.13)',
     119'14':'Derived forecasts based on a cluster of ensemble members over a circular area at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval. (see Template 4.14)',
     120'15':'Average, accumulation, extreme values or other statistically-processed values over a spatial area at a horizontal level or in a horizontal layer at a point in time. (see Template 4.15)',
     121'16-19':'Reserved',
     122'20':'Radar product (see Template 4.20)',
     123'21-29':'Reserved',
     124'30':'Satellite product (see Template 4.30)  NOTE: This template is deprecated. Template 4.31 should be used instead.',
     125'31':'Satellite product (see Template 4.31)',
     126'32':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for simulate (synthetic) satellite data (see Template 4.32)',
     127'33':'Individual Ensemble Forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for simulated (synthetic) satellite data (see Template 4.33)',
     128'34':'Individual Ensemble Forecast, control and perturbed, at a horizontal level or in a horizontal layer, in a continuous or non-continuous interval for simulated (synthetic) satellite data(see Template 4.34)',
     129'35':'Satellite product with or without associated quality values (see Template 4.35)',
     130'36-39':'Reserved',
     131'40':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for atmospheric chemical constituents. (see Template 4.40)',
     132'41':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for atmospheric chemical constituents. (see Template 4.41)',
     133'42':'Average, accumulation, and/or extreme values or other statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for atmospheric chemical constituents. (see Template 4.42)',
     134'43':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval for atmospheric chemical constituents. (see Template 4.43)',
     135'44':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for aerosol. (see Template 4.44)',
     136'45':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval for aerosol. (see Template 4.45)',
     137'46':'Average, accumulation, and/or extreme values or other statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for aerosol. (see Template 4.46)',
     138'47':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval for aerosol. (see Template 4.47)',
     139'48':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for aerosol. (see Template 4.48)',
     140'49':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for optical properties of aerosol.  (see Template 4.49)',
     141'50':'Reserved',
     142'51':'Categorical forecast at a horizontal level or in a horizontal layer at a point in time. (see Template 4.51)',
     143'52':'Reserved',
     144'53':'Partitioned parameters at a horizontal level or horizontal layer at a point in time. (see Template 4.53)',
     145'54':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for partitioned parameters. (see Template 4.54)',
     146'55':'Spatio-temporal changing tiles at a horizontal level or horizontal layer at a point in time (see Template 4.55)',
     147'56':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for spatio-temporal changing tile parameters. (see Template 4.56)',
     148'57':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for atmospheric chemical constituents based on a distribution function (see Template 4.57)',
     149'58':'Individual Ensemble Forecast, Control and Perturbed, at a  horizontal level or in a horizontal layer at a point in time interval for  Atmospheric Chemical Constituents based on a distribution function  (see Template 4.58)',
     150'59':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for spatio-temporal changing tile parameters (corrected version of template 4.56 - See Template 4.59)',
     151'60':'Individual Ensemble Reforecast, control and perturbed, at  a horizontal level or in a horizontal layer at a point in time.  (see Template 4.60)',
     152'61':'Individual Ensemble Reforecast, control and perturbed, at  a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval  (see Template 4.61)',
     153'62':'Average, Accumulation and/or Extreme values or other Statistically-processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for spatio-temporal changing tiles at a horizontal level or horizontal layer at a point in time  (see Template 4.62)',
     154'63':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for spatio-temporal changing tiles  (see Template 4.63)',
     155'64-66':'Reserved',
     156'67':'Average, accumulation and/or extreme values or other statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for atmospheric chemical constituents based on a distribution function  (see Template 4.67)',
     157'68':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for  atmospheric chemical constituents based on a distribution function.  (see Template 4.68)',
     158'69':'Reserved',
     159'70':'Post-processing analysis or forecast at a horizontal level or in a horizontal  layer at a point in time.  (see Template 4.70)',
     160'71':'Post-processing individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time.  (see Template 4.71)',
     161'72':'Post-processing average, accumulation, extreme values or other  statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval.  (see Template 4.72)',
     162'73':'Post-processing individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer, in a continuous or non-continuous time interval.  (see Template 4.73)',
     163'74-75':'Reserved',
     164'76':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for atmospheric chemical constituents with source or sink.  (see Template 4.76)',
     165'77':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for atmospheric chemical constituents with source or sink.  (see Template 4.77)',
     166'78':'Average, accumulation, and/or extreme values or other statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for atmospheric chemical constituents with source or sink.  (see Template 4.78)',
     167'79':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for atmospheric chemical constituents with source or sink.  (see Template 4.79)',
     168'80':'Analysis or forecast at a horizontal level or in a horizontal layer at a point in time for optical properties of aerosol with source or sink.  (see Template 4.80)',
     169'81':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time for optical properties of aerosol with source or sink.  (see Template 4.81)',
     170'82':'Average, accumulation, and/or extreme values or other statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for aerosol with source or sink.  (see Template 4.82)',
     171'83':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for aerosol with source or sink.  (see Template 4.83)',
     172'84':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for aerosol with source or sink.  (see Template 4.84)',
     173'85':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval for aerosol.  (see Template 4.85)',
     174'86':'Quantile forecasts at a horizontal level or in a horizontal layer at a point in time.  (see Template 4.86)',
     175'87':'Quantile forecasts at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval.  (see Template 4.87)',
     176'88':'Analysis or forecast at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.88)',
     177'89-90':'Reserved',
     178'91':'Categorical forecast at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval. (see Template 4.91)',
     179'92':'Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.92)',
     180'93':'Post-processing analysis or forecast at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.93)',
     181'94':'Post-processing individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.94)',
     182'95':'Average, accumulation, extreme values or other statiscally processed value at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.95)',
     183'96':'Average, accumulation, extreme values or other statistically processed values of an individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.96)',
     184'97':'Average, accumulation, extreme values or other statistically processed values of post-processing analysis or forecast at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.97)',
     185'98':'Average, accumulation, extreme values or other statistically processed values of a post-processing individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a specified local time.  (see Template 4.98)',
     186'99-253':'Reserved',
     187'254':'CCITT IA5 character string (see Template 4.254)',
     188'255-999':'Reserved',
     189'1000':'Cross-section of analysis and forecast at a point in time. (see Template 4.1000)',
     190'1001':'Cross-section of averaged or otherwise statistically processed analysis or forecast over a range of time. (see Template 4.1001)',
     191'1002':'Cross-section of analysis and forecast, averaged or otherwise statistically-processed over latitude or longitude. (see Template 4.1002)',
     192'1003-1099':'Reserved',
     193'1100':'Hovmoller-type grid with no averaging or other statistical processing (see Template 4.1100)',
     194'1101':'Hovmoller-type grid with averaging or other statistical processing (see Template 4.1101)',
     195'1102-32767':'Reserved',
     196'32768-65534':'Reserved for Local Use',
     197'65535':'Missing',
     198}
     199
     200table_4_3 = {
     201'0':'Analysis',
     202'1':'Initialization',
     203'2':'Forecast',
     204'3':'Bias Corrected Forecast',
     205'4':'Ensemble Forecast',
     206'5':'Probability Forecast',
     207'6':'Forecast Error',
     208'7':'Analysis Error',
     209'8':'Observation',
     210'9':'Climatological',
     211'10':'Probability-Weighted Forecast',
     212'11':'Bias-Corrected Ensemble Forecast',
     213'12':'Post-processed Analysis (See Note)',
     214'13':'Post-processed Forecast (See Note)',
     215'14':'Nowcast',
     216'15':'Hindcast',
     217'16':'Physical Retrieval',
     218'17':'Regression Analysis',
     219'18':'Difference Between Two Forecasts',
     220'19-191':'Reserved',
     221'192-254':'Reserved for Local Use',
     222'192':'Forecast Confidence Indicator',
     223'193':'Probability-matched Mean',
     224'194':'Neighborhood Probability',
     225'195':'Bias-Corrected and Downscaled Ensemble Forecast',
     226'196':'Perturbed Analysis for Ensemble Initialization',
     227'197':'Ensemble Agreement Scale Probability',
     228'198':'Post-Processed Deterministic-Expert-Weighted Forecast',
     229'199':'Ensemble Forecast Based on Counting',
     230'200':'Local Probability-matched Mean',
     231'255':'Missing',
     232}
     233
     234table_4_4 = {
     235'0':'Minute',
     236'1':'Hour',
     237'2':'Day',
     238'3':'Month',
     239'4':'Year',
     240'5':'Decade (10 Years)',
     241'6':'Normal (30 Years)',
     242'7':'Century (100 Years)',
     243'8':'Reserved',
     244'9':'Reserved',
     245'10':'3 Hours',
     246'11':'6 Hours',
     247'12':'12 Hours',
     248'13':'Second',
     249'14-191':'Reserved',
     250'192-254':'Reserved for Local Use',
     251'255':'Missing',
     252}
     253
     254table_4_5 = {
     255'0':['Reserved','unknown'],
     256'1':['Ground or Water Surface','unknown'],
     257'2':['Cloud Base Level','unknown'],
     258'3':['Level of Cloud Tops','unknown'],
     259'4':['Level of 0o C Isotherm','unknown'],
     260'5':['Level of Adiabatic Condensation Lifted from the Surface','unknown'],
     261'6':['Maximum Wind Level','unknown'],
     262'7':['Tropopause','unknown'],
     263'8':['Nominal Top of the Atmosphere','unknown'],
     264'9':['Sea Bottom','unknown'],
     265'10':['Entire Atmosphere','unknown'],
     266'11':['Cumulonimbus Base (CB)','m'],
     267'12':['Cumulonimbus Top (CT)','m'],
     268'13':['Lowest level where vertically integrated  cloud cover exceeds the specified percentage (cloud base for a given percentage cloud cover)','%'],
     269'14':['Level of free convection (LFC)','unknown'],
     270'15':['Convection condensation level (CCL)','unknown'],
     271'16':['Level of neutral buoyancy or equilibrium (LNB)','unknown'],
     272'17-19':['Reserved','unknown'],
     273'20':['Isothermal Level','K'],
     274'21':['Lowest level where mass density exceeds the specified value  (base for a given threshold of mass density)','kg m-3'],
     275'22':['Highest level where mass density exceeds the specified value (top for a given threshold of mass density)','kg m-3'],
     276'23':['Lowest level where air concentration exceeds the specified value (base for a given threshold of air concentration','Bq m-3'],
     277'24':['Highest level where air concentration exceeds the specified  value (top for a given threshold of air concentration)','Bq m-3'],
     278'25':['Highest level where radar reflectivity exceeds the specified  value (echo top for a given threshold of reflectivity)','dBZ'],
     279'26':['Convective cloud layer base','m'],
     280'27':['Convective cloud layer top','m'],
     281'28-29':['Reserved','unknown'],
     282'30':['Specified radius from the centre of the Sun','m'],
     283'31':['Ionospheric D-region level','unknown'],
     284'32':['Ionospheric E-region level','unknown'],
     285'33':['Ionospheric F1-region level','unknown'],
     286'34':['Ionospheric F1-region level','unknown'],
     287'35':['Ionospheric F2-region level','unknown'],
     288'36-99':['Reserved','unknown'],
     289'100':['Isobaric Surface','Pa'],
     290'101':['Mean Sea Level','unknown'],
     291'102':['Specific Altitude Above Mean Sea Level','m'],
     292'103':['Specified Height Level Above Ground','m'],
     293'104':['Sigma Level','unknown'],
     294'105':['Hybrid Level','unknown'],
     295'106':['Depth Below Land Surface','m'],
     296'107':['Isentropic (theta) Level','K'],
     297'108':['Level at Specified Pressure Difference from Ground to Level','Pa'],
     298'109':['Potential Vorticity Surface','K m2 kg-1 s-1'],
     299'110':['Reserved','unknown'],
     300'111':['Eta Level','unknown'],
     301'112':['Reserved','unknown'],
     302'113':['Logarithmic Hybrid Level','unknown'],
     303'114':['Snow Level','Numeric'],
     304'115':['Sigma height level','unknown'],
     305'116':['Reserved','unknown'],
     306'117':['Mixed Layer Depth','m'],
     307'118':['Hybrid Height Level','unknown'],
     308'119':['Hybrid Pressure Level','unknown'],
     309'120-149':['Reserved','unknown'],
     310'150':['Generalized Vertical Height Coordinate','unknown'],
     311'151':['Soil level','Numeric'],
     312'152':['Sea-ice level,(see Note 8)','Numeric'],
     313'153-159':['Reserved','unknown'],
     314'160':['Depth Below Sea Level','m'],
     315'161':['Depth Below Water Surface','m'],
     316'162':['Lake or River Bottom','unknown'],
     317'163':['Bottom Of Sediment Layer','unknown'],
     318'164':['Bottom Of Thermally Active Sediment Layer','unknown'],
     319'165':['Bottom Of Sediment Layer Penetrated By Thermal Wave','unknown'],
     320'166':['Mixing Layer','unknown'],
     321'167':['Bottom of Root Zone','unknown'],
     322'168':['Ocean Model Level','Numeric'],
     323'169':['Ocean level defined by water density (sigma-theta)  difference from near-surface to level','kg m-3'],
     324'170':['Ocean level defined by water potential temperature  difference from near-surface to level','K'],
     325'171':['Ocean level defined by vertical eddy diffusivity difference from near-surface to level,(see Note 7)','m2 s-1'],
     326'172-173':['Reserved','unknown'],
     327'174':['Top Surface of Ice on Sea, Lake or River','unknown'],
     328'175':['Top Surface of Ice, under Snow, on Sea, Lake or River','unknown'],
     329'176':['Bottom Surface (underside) Ice on Sea, Lake or River','unknown'],
     330'177':['Deep Soil (of indefinite depth)','unknown'],
     331'178':['Reserved','unknown'],
     332'179':['Top Surface of Glacier Ice and Inland Ice','unknown'],
     333'180':['Deep Inland or Glacier Ice (of indefinite depth)','unknown'],
     334'181':['Grid Tile Land Fraction as a Model Surface','unknown'],
     335'182':['Grid Tile Water Fraction as a Model Surface','unknown'],
     336'183':['Grid Tile Ice Fraction on Sea, Lake or River as a Model Surface','unknown'],
     337'184':['Grid Tile Glacier Ice and Inland Ice Fraction as a Model Surface','unknown'],
     338'185-191':['Reserved','unknown'],
     339'192-254':['Reserved for Local Use','unknown'],
     340'200':['Entire atmosphere (considered as a single layer)','unknown'],
     341'201':['Entire ocean (considered as a single layer)','unknown'],
     342'204':['Highest tropospheric freezing level','unknown'],
     343'206':['Grid scale cloud bottom level','unknown'],
     344'207':['Grid scale cloud top level','unknown'],
     345'209':['Boundary layer cloud bottom level','unknown'],
     346'210':['Boundary layer cloud top level','unknown'],
     347'211':['Boundary layer cloud layer','unknown'],
     348'212':['Low cloud bottom level','unknown'],
     349'213':['Low cloud top level','unknown'],
     350'214':['Low cloud layer','unknown'],
     351'215':['Cloud ceiling','unknown'],
     352'216':['Effective Layer Top Level','m'],
     353'217':['Effective Layer Bottom Level','m'],
     354'218':['Effective Layer','m'],
     355'220':['Planetary Boundary Layer','unknown'],
     356'221':['Layer Between Two Hybrid Levels','unknown'],
     357'222':['Middle cloud bottom level','unknown'],
     358'223':['Middle cloud top level','unknown'],
     359'224':['Middle cloud layer','unknown'],
     360'232':['High cloud bottom level','unknown'],
     361'233':['High cloud top level','unknown'],
     362'234':['High cloud layer','unknown'],
     363'235':['Ocean Isotherm Level (1/10 ° C)','unknown'],
     364'236':['Layer between two depths below ocean surface','unknown'],
     365'237':['Bottom of Ocean Mixed Layer (m)','unknown'],
     366'238':['Bottom of Ocean Isothermal Layer (m)','unknown'],
     367'239':['Layer Ocean Surface  and 26C Ocean Isothermal Level','unknown'],
     368'240':['Ocean Mixed Layer','unknown'],
     369'241':['Ordered Sequence of Data','unknown'],
     370'242':['Convective cloud bottom level','unknown'],
     371'243':['Convective cloud top level','unknown'],
     372'244':['Convective cloud layer','unknown'],
     373'245':['Lowest level of the wet bulb zero','unknown'],
     374'246':['Maximum equivalent potential temperature level','unknown'],
     375'247':['Equilibrium level','unknown'],
     376'248':['Shallow convective cloud bottom level','unknown'],
     377'249':['Shallow convective cloud top level','unknown'],
     378'251':['Deep convective cloud bottom level','unknown'],
     379'252':['Deep convective cloud top level','unknown'],
     380'253':['Lowest bottom level of supercooled liquid water layer','unknown'],
     381'254':['Highest top level of supercooled liquid water layer','unknown'],
     382'255':['Missing','unknown'],
     383}
     384
     385table_4_6 = {
     386'0':'Unperturbed High-Resolution Control Forecast',
     387'1':'Unperturbed Low-Resolution Control Forecast',
     388'2':'Negatively Perturbed Forecast',
     389'3':'Positively Perturbed Forecast',
     390'4':'Multi-Model Forecast',
     391'5-191':'Reserved',
     392'192-254':'Reserved for Local Use',
     393'192':'Perturbed Ensemble Member',
     394'255':'Missing',
     395}
     396
     397table_4_7 = {
     398'0':'Unweighted Mean of All Members',
     399'1':'Weighted Mean of All Members',
     400'2':'Standard Deviation with respect to Cluster Mean',
     401'3':'Standard Deviation with respect to Cluster Mean, Normalized',
     402'4':'Spread of All Members',
     403'5':'Large Anomaly Index of All Members',
     404'6':'Unweighted Mean of the Cluster Members',
     405'7':'Interquartile Range (Range between the 25th and 75th quantile)',
     406'8':'Minimum Of All Ensemble Members',
     407'9':'Maximum Of All Ensemble Members',
     408'10-191':'Reserved',
     409'192-254':'Reserved for Local Use',
     410'192':'Unweighted Mode of All Members',
     411'193':'Percentile value (10%) of All Members',
     412'194':'Percentile value (50%) of All Members',
     413'195':'Percentile value (90%) of All Members',
     414'196':'Statistically decided weights for each ensemble member',
     415'197':'Climate Percentile (percentile values from climate distribution)',
     416'198':'Deviation of Ensemble Mean from Daily Climatology',
     417'199':'Extreme Forecast Index',
     418'200':'Equally Weighted Mean',
     419'201':'Percentile value (5%) of All Members',
     420'202':'Percentile value (25%) of All Members',
     421'203':'Percentile value (75%) of All Members',
     422'204':'Percentile value (95%) of All Members',
     423'255':'Missing',
     424}
     425
     426table_4_8 = {
     427'0':'Anomoly Correlation',
     428'1':'Root Mean Square',
     429'2-191':'Reserved',
     430'192-254':'Reserved for Local Use',
     431'255':'Missing',
     432}
     433
     434table_4_9 = {
     435'0':'Probability of event below lower limit',
     436'1':'Probability of event above upper limit',
     437'2':'Probability of event between upper and lower limits (the range includes lower limit but no the upper limit)',
     438'3':'Probability of event above lower limit',
     439'4':'Probability of event below upper limit',
     440'5':'Probability of event equal to lower limit',
     441'6':'Probability of event in above normal category (see Notes 1 and 2)',
     442'9-191':'Reserved',
     443'192-254':'Reserved for Local Use',
     444'255':'Missing',
     445}
     446
     447table_4_10 = {
     448'0':'Average',
     449'1':'Accumulation',
     450'2':'Maximum',
     451'3':'Minimum',
     452'4':'Difference (value at the end of the time range minus value at the beginning)',
     453'5':'Root Mean Square',
     454'6':'Standard Deviation',
     455'7':'Covariance (temporal variance)',
     456'8':'Difference ( value at the beginning of the time range minus value at the end)',
     457'9':'Ratio',
     458'13-191':'Reserved',
     459'192-254':'Reserved for Local Use',
     460'192':'Climatological Mean Value: multiple year averages of quantities which are themselves means over some period of time (P2) less than a year. The reference time (R) indicates the date and time of the start of a period of time, given by R to R + P2, over which a mean is formed; N indicates the number of such period-means that are averaged together to form the climatological value, assuming that the N period-mean fields are separated by one year. The reference time indicates the start of the N-year climatology. N is given in octets 22-23 of the PDS.  If P1 = 0 then the data averaged in the basic interval P2 are assumed to be continuous, i.e., all available data are simply averaged together.  If P1 = 1 (the units of time - octet 18, code table 4 - are not relevant here) then the data averaged together in the basic interval P2 are valid only at the time (hour, minute) given in the reference time, for all the days included in the P2 period. The units of P2 are given by the contents of octet 18 and Table 4.',
     461'193':'Average of N forecasts (or initialized analyses); each product has forecast period of P1 (P1=0 for initialized analyses); products have reference times at intervals of P2, beginning at the given reference time.',
     462'194':'Average of N uninitialized analyses, starting at reference time, at intervals of P2.',
     463'195':'Average of forecast accumulations. P1 = start of accumulation period. P2 = end of accumulation period. Reference time is the start time of the first forecast, other forecasts at 24-hour intervals. Number in Ave = number of forecasts used.',
     464'196':'Average of successive forecast accumulations. P1 = start of accumulation period. P2 = end of accumulation period. Reference time is the start time of the first forecast, other forecasts at (P2 - P1) intervals. Number in Ave = number of forecasts used',
     465'197':'Average of forecast averages. P1 = start of averaging period. P2 = end of averaging period. Reference time is the start time of the first forecast, other forecasts at 24-hour intervals. Number in Ave = number of forecast used',
     466'198':'Average of successive forecast averages. P1 = start of averaging period. P2 = end of averaging period. Reference time is the start time of the first forecast, other forecasts at (P2 - P1) intervals. Number in Ave = number of forecasts used',
     467'199':'Climatological Average of N analyses, each a year apart, starting from initial time R and for the period from R+P1 to R+P2.',
     468'200':'Climatological Average of N forecasts, each a year apart, starting from initial time R and for the period from R+P1 to R+P2.',
     469'201':'Climatological Root Mean Square difference between N forecasts and their verifying analyses, each a year apart, starting with initial time R and for the period from R+P1 to R+P2.',
     470'202':'Climatological Standard Deviation of N forecasts from the mean of the same N forecasts, for forecasts one year apart. The first forecast starts wtih initial time R and is for the period from R+P1 to R+P2.',
     471'203':'Climatological Standard Deviation of N analyses from the mean of the same N analyses, for analyses one year apart. The first analyses is valid for period R+P1 to R+P2.',
     472'204':'Average of forecast accumulations. P1 = start of accumulation period. P2 = end of accumulation period. Reference time is the start time of the first forecast, other forecasts at 6-hour intervals. Number in Ave = number of forecast used',
     473'205':'Average of forecast averages. P1 = start of averaging period. P2 = end of averaging period. Reference time is the start time of the first forecast, other forecasts at 6-hour intervals. Number in Ave = number of forecast used',
     474'206':'Average of forecast accumulations. P1 = start of accumulation period. P2 = end of accumulation period. Reference time is the start time of the first forecast, other forecasts at 12-hour intervals. Number in Ave = number of forecast used',
     475'207':'Average of forecast averages. P1 = start of averaging period. P2 = end of averaging period. Reference time is the start time of the first forecast, other forecasts at 12-hour intervals. Number in Ave = number of forecast used',
     476'255':'Missing',
     477}
     478
     479table_4_11 = {
     480'0':'Reserved',
     481'1':'Successive times processed have same forecast time, start time of forecast is incremented.',
     482'2':'Successive times processed have same start time of forecast, forecast time is incremented.',
     483'3':'Successive times processed have start time of forecast incremented and forecast time decremented so that valid time remains constant.',
     484'4':'Successive times processed have start time of forecast decremented and forecast time incremented so that valid time remains constant.',
     485'5':'Floating subinterval of time between forecast time and end of overall time interval.(see Note 1)',
     486'6-191':'Reserved',
     487'192-254':'Reserved for Local Use',
     488'255':'Missing',
     489}
     490
     491table_4_15 = {
     492'0':'Data is calculated directly from the source grid with no interpolation',
     493'1':'Bilinear interpolation using the 4 source grid grid-point values surrounding the nominal grid-point',
     494'2':'Bicubic interpolation using the 4 source grid grid-point values surrounding the nominal grid-point',
     495'3':'Using the value from the source grid grid-point  which is nearest to the nominal grid-point',
     496'4':'Budget interpolation using the 4 source grid grid-point values surrounding the nominal grid-point',
     497'5':'Spectral interpolation using the 4 source grid grid-point values surrounding the nominal grid-point',
     498'6':'Neighbor-budget interpolation using the 4 source grid grid-point values surrounding the nominal grid-point',
     499'7-191':'Reserved',
     500'192-254':'Reserved for Local Use',
     501'255':'Missing',
     502}
     503
     504table_4_201 = {
     505'0':'Reserved',
     506'1':'Rain',
     507'2':'Thunderstorm',
     508'3':'Freezing Rain',
     509'4':'Mixed/Ice',
     510'5':'Snow',
     511'6':'Wet Snow',
     512'7':'Mixture of Rain and Snow',
     513'8':'Ice Pellets',
     514'9':'Graupel',
     515'10':'Hail',
     516'11':'Drizzle',
     517'12':'Freezing Drizzle',
     518'13-191':'Reserved',
     519'192-254':'Reserved for Local Use',
     520'255':'Missing',
     521}
     522
     523table_4_202 = {
     524'0-191':'Reserved',
     525'192-254':'Reserved for Local Use',
     526'255':'Missing',
     527}
     528
     529table_4_203 = {
     530'0':'Clear',
     531'1':'Cumulonimbus',
     532'2':'Stratus',
     533'3':'Stratocumulus',
     534'4':'Cumulus',
     535'5':'Altostratus',
     536'6':'Nimbostratus',
     537'7':'Altocumulus',
     538'8':'Cirrostratus',
     539'9':'Cirrorcumulus',
     540'10':'Cirrus',
     541'11':'Cumulonimbus - ground-based fog beneath the lowest layer',
     542'12':'Stratus - ground-based fog beneath the lowest layer',
     543'13':'Stratocumulus - ground-based fog beneath the lowest layer',
     544'14':'Cumulus - ground-based fog beneath the lowest layer',
     545'15':'Altostratus - ground-based fog beneath the lowest layer',
     546'16':'Nimbostratus - ground-based fog beneath the lowest layer',
     547'17':'Altocumulus - ground-based fog beneath the lowest layer',
     548'18':'Cirrostratus - ground-based fog beneath the lowest layer',
     549'19':'Cirrorcumulus - ground-based fog beneath the lowest layer',
     550'20':'Cirrus - ground-based fog beneath the lowest layer',
     551'21-190':'Reserved',
     552'191':'Unknown',
     553'192-254':'Reserved for Local Use',
     554'255':'Missing',
     555}
     556
     557table_4_204 = {
     558'0':'None',
     559'1':'Isolated (1-2%)',
     560'2':'Few (3-5%)',
     561'3':'Scattered (16-45%)',
     562'4':'Numerous (>45%)',
     563'5-191':'Reserved',
     564'192-254':'Reserved for Local Use',
     565'255':'Missing',
     566}
     567
     568table_4_205 = {
     569'0':'Aerosol not present',
     570'1':'Aerosol present',
     571'2-191':'Reserved',
     572'192-254':'Reserved for Local Use',
     573'255':'Missing',
     574}
     575
     576table_4_206 = {
     577'0':'Not Present',
     578'1':'Present',
     579'2-191':'Reserved',
     580'192-254':'Reserved for Local Use',
     581'255':'Missing',
     582}
     583
     584table_4_207 = {
     585'0':'None',
     586'1':'Light',
     587'2':'Moderate',
     588'3':'Severe',
     589'4':'Trace',
     590'5':'Heavy',
     591'6-191':'Reserved',
     592'192-254':'Reserved for Local Use',
     593'255':'Missing',
     594}
     595
     596table_4_208 = {
     597'0':'None',
     598'1':'Light',
     599'2':'Moderate',
     600'3':'Severe',
     601'4':'Extreme',
     602'5-191':'Reserved',
     603'192-254':'Reserved for Local Use',
     604'255':'Missing',
     605}
     606
     607table_4_209 = {
     608'0':'Reserved',
     609'1':'Stable',
     610'2':'Mechanically-Driven Turbulence',
     611'3':'Force Convection',
     612'4':'Free Convection',
     613'5-191':'Reserved',
     614'192-254':'Reserved for Local Use',
     615'255':'Missing',
     616}
     617
     618table_4_210 = {
     619'0':'Contrail Not Present',
     620'1':'Contrail Present',
     621'2-191':'Reserved',
     622'192-254':'Reserved for Local Use',
     623'255':'Missing',
     624}
     625
     626table_4_211 = {
     627'0':'Low Bypass',
     628'1':'High Bypass',
     629'2':'Non-Bypass',
     630'3-191':'Reserved',
     631'192-254':'Reserved for Local Use',
     632'255':'Missing',
     633}
     634
     635table_4_212 = {
     636'0':'Reserved',
     637'1':'Urban Land',
     638'2':'Agricultural',
     639'3':'Range Land',
     640'4':'Deciduous Forest',
     641'5':'Coniferous Forest',
     642'6':'Forest/Wetland',
     643'7':'Water',
     644'8':'Wetlands',
     645'9':'Desert',
     646'10':'Tundra',
     647'11':'Ice',
     648'12':'Tropical Forest',
     649'13':'Savannah',
     650'14-191':'Reserved',
     651'192-254':'Reserved for Local Use',
     652'255':'Missing',
     653}
     654
     655table_4_213 = {
     656'0':'Reserved',
     657'1':'Sand',
     658'2':'Loamy Sand',
     659'3':'Sandy Loam',
     660'4':'Silt Loam',
     661'5':'Organic',
     662'6':'Sandy Clay Loam',
     663'7':'Silt Clay Loam',
     664'8':'Clay Loam',
     665'9':'Sandy Clay',
     666'10':'Silty Clay',
     667'11':'Clay',
     668'12-191':'Reserved',
     669'192-254':'Reserved for Local Use',
     670'255':'Missing',
     671}
     672
     673table_4_215 = {
     674'0-49':'Reserved',
     675'50':'No-Snow/No-Cloud',
     676'51-99':'Reserved',
     677'100':'Clouds',
     678'101-249':'Reserved',
     679'250':'Snow',
     680'192-254':'Reserved for Local Use',
     681'255':'Missing',
     682}
     683
     684table_4_216 = {
     685'0-90':'Elevation in increments of 100 m',
     686'91-253':'Reserved',
     687'254':'Clouds',
     688'255':'Missing',
     689}
     690
     691table_4_217 = {
     692'0':'Clear over water',
     693'1':'Clear over land',
     694'2':'Cloud',
     695'3':'No data',
     696'4-191':'Reserved',
     697'192-254':'Reserved for Local Use',
     698'255':'Missing',
     699}
     700
     701table_4_218 = {
     702'0':'No Scene Identified',
     703'1':'Green Needle-Leafed Forest',
     704'2':'Green Broad-Leafed Forest',
     705'3':'Deciduous Needle-Leafed Forest',
     706'4':'Deciduous Broad-Leafed Forest',
     707'5':'Deciduous Mixed Forest',
     708'6':'Closed Shrub-Land',
     709'7':'Open Shrub-Land',
     710'8':'Woody Savannah',
     711'9':'Savannah',
     712'10':'Grassland',
     713'11':'Permanent Wetland',
     714'12':'Cropland',
     715'13':'Urban',
     716'14':'Vegetation / Crops',
     717'15':'Permanent Snow / Ice',
     718'16':'Barren Desert',
     719'17':'Water Bodies',
     720'18':'Tundra',
     721'19':'Warm Liquid Water Cloud',
     722'20':'Supercooled Liquid Water Cloud',
     723'21':'Mixed Phase Cloud',
     724'22':'Optically Thin Ice Cloud',
     725'23':'Optically Thick Ice Cloud',
     726'24':'Multi-Layeblack Cloud',
     727'25-96':'Reserved',
     728'97':'Snow / Ice on Land',
     729'98':'Snow / Ice on Water',
     730'99':'Sun-Glint',
     731'100':'General Cloud',
     732'101':'Low Cloud / Fog / Stratus',
     733'102':'Low Cloud / Stratocumulus',
     734'103':'Low Cloud / Unknown Type',
     735'104':'Medium Cloud / Nimbostratus',
     736'105':'Medium Cloud / Altostratus',
     737'106':'Medium Cloud / Unknown Type',
     738'107':'High Cloud / Cumulus',
     739'108':'High Cloud / Cirrus',
     740'109':'High Cloud / Unknown Type',
     741'110':'Unknown Cloud Type',
     742'111':'Single layer water cloud',
     743'112':'Single layer ice cloud',
     744'113-191':'Reserved',
     745'192-254':'Reserved for Local Use',
     746'255':'Missing',
     747}
     748
     749table_4_222 = {
     750'0':'No',
     751'1':'Yes',
     752'2-191':'Reserved',
     753'192-254':'Reserved for Local Use',
     754'255':'Missing',
     755}
     756
     757table_4_223 = {
     758'0':'No Fire Detected',
     759'1':'Possible Fire Detected',
     760'2':'Probable Fire Detected',
     761'3':'Missing',
     762'4-191':'Reserved',
     763'192-254':'Reserved for Local Use',
     764'255':'Missing',
     765}
     766
     767table_4_224 = {
     768'0':'No Risk Area',
     769'1':'Reserved',
     770'2':'General Thunderstorm Risk Area',
     771'3':'Reserved',
     772'4':'Slight Risk Area',
     773'5':'Reserved',
     774'6':'Moderate Risk Area',
     775'7':'Reserved',
     776'8':'High Risk Area',
     777'9-10':'Reserved',
     778'11':'Dry Thunderstorm (Dry Lightning) Risk Area',
     779'12-13':'Reserved',
     780'14':'Critical Risk Area',
     781'15-17':'Reserved',
     782'18':'Extreamly Critical Risk Area',
     783'19-191':'Reserved',
     784'192-254':'Reserved for Local Use',
     785'255':'Missing',
     786}
     787
     788table_4_227 = {
     789'0':'None',
     790'1':'General',
     791'2':'Convective',
     792'3':'Stratiform',
     793'4':'Freezing',
     794'5-191':'Reserved',
     795'192-254':'Reserved for Local Use',
     796'255':'Missing',
     797}
     798
     799table_4_228 = {
     800'0':'None',
     801'1':'Trace',
     802'2':'Light',
     803'3':'Moderate',
     804'4':'Severe',
     805'6-191':'Reserved',
     806'192-254':'Reserved for Local Use',
     807'255':'Missing',
     808}
     809
     810table_4_243 = {
     811'0':'Reserved',
     812'1':'Evergreen broadleaved forest',
     813'2':'Deciduous broadleaved closed forest',
     814'3':'Deciduous broadleaved open forest',
     815'4':'Evergreen needle-leaf forest',
     816'5':'Deciduous needle-leaf forest',
     817'6':'Mixed leaf trees',
     818'7':'Fresh water flooded trees',
     819'8':'Saline water flooded trees',
     820'9':'Mosaic tree/natural vegetation',
     821'10':'Burnt tree cover',
     822'11':'Evergreen shurbs closed-open',
     823'12':'Deciduous shurbs closed-open',
     824'13':'Herbaceous vegetation closed-open',
     825'14':'Sparse herbaceous or grass',
     826'15':'Flooded shurbs or herbaceous',
     827'16':'Cultivated and managed areas',
     828'17':'Mosaic crop/tree/natural vegetation',
     829'18':'Mosaic crop/shrub/grass',
     830'19':'Bare areas',
     831'20':'Water',
     832'21':'Snow and ice',
     833'22':'Artificial surface',
     834'23':'Ocean',
     835'24':'Irrigated croplands',
     836'25':'Rain fed croplands',
     837'26':'Mosaic cropland (50-70%)-vegetation (20-50%)',
     838'27':'Mosaic vegetation (50-70%)-cropland (20-50%)',
     839'28':'Closed broadleaved evergreen forest',
     840'29':'Closed needle-leaved evergreen forest',
     841'30':'Open needle-leaved deciduous forest',
     842'31':'Mixed broadleaved and needle-leave forest',
     843'32':'Mosaic shrubland (50-70%)-grassland (20-50%)',
     844'33':'Mosaic grassland (50-70%)-shrubland (20-50%)',
     845'34':'Closed to open shrubland',
     846'35':'Sparse vegetation',
     847'36':'Closed to open forest regularly flooded',
     848'37':'Closed forest or shrubland permanently flooded',
     849'38':'Closed to open grassland regularly flooded',
     850'39':'Undefined',
     851'40-191':'Reserved',
     852'192-254':'Reserved for Local Use',
     853'255':'Missing',
     854}
     855
     856table_scale_time_hours = {
     857'0': 60.,
     858'1': 1.,
     859'2': float(1.0/24.0),
     860'3': float(1.0/720.0),
     861'4': float(1.0/(365.0*24.0)),
     862'5': float(1.0/(10.0*365.0*24.0)),
     863'6': float(1.0/(30.0*365.0*24.0)),
     864'7': float(1.0/(100.0*365.0*24.0)),
     865'8': 1.,
     866'9': 1.,
     867'10': 3.,
     868'11': 6.,
     869'12': 12.,
     870'13': 3600.,
     871'14-255': 1.}
     872
     873# ----------------------------------------------------------------------------------------
     874# Source: https://github.com/NOAA-EMC/NCEPLIBS-wgrib2/blob/develop/wgrib2/Level.c
     875#
     876# The dictionary key is the Section 4.5 coded value.  The value is a list where the
     877# index 0 is the string to use for level and index 1 is the string for a layer.
     878# ----------------------------------------------------------------------------------------
     879table_wgrib2_level_string = {
     880'0': ["reserved","reserved"],
     881'1': ["surface","reserved"],
     882'2': ["cloud base","reserved"],
     883'3': ["cloud top","reserved"],
     884'4': ["0C isotherm","reserved"],
     885'5': ["level of adiabatic condensation from sfc","reserved"],
     886'6': ["max wind","reserved"],
     887'7': ["tropopause","reserved"],
     888'8': ["top of atmosphere","reserved"],
     889'9': ["sea bottom","reserved"],
     890'10': ["entire atmosphere","reserved"],
     891'11': ["cumulonimbus base","reserved"],
     892'12': ["cumulonimbus top","reserved"],
     893'13': ["lowest level %g%% integrated cloud cover","reserved"],
     894'14': ["level of free convection","reserved"],
     895'15': ["convection condensation level","reserved"],
     896'16': ["level of neutral buoyancy","reserved"],
     897'17': ["reserved","reserved"],
     898'18': ["reserved","reserved"],
     899'19': ["reserved","reserved"],
     900'20': ["%g K level","reserved"],
     901'21': ["lowest level > %g kg/m^3","reserved"],
     902'22': ["highest level > %g kg/m^3","reserved"],
     903'23': ["lowest level > %g Bq/m^3","reserved"],
     904'24': ["highest level > %g Bg/m^3","reserved"],
     905'25': ["reserved","reserved"],
     906'26': ["reserved","reserved"],
     907'27': ["reserved","reserved"],
     908'28': ["reserved","reserved"],
     909'29': ["reserved","reserved"],
     910'30': ["reserved","reserved"],
     911'31': ["reserved","reserved"],
     912'32': ["reserved","reserved"],
     913'33': ["reserved","reserved"],
     914'34': ["reserved","reserved"],
     915'35': ["reserved","reserved"],
     916'36': ["reserved","reserved"],
     917'37': ["reserved","reserved"],
     918'38': ["reserved","reserved"],
     919'39': ["reserved","reserved"],
     920'40': ["reserved","reserved"],
     921'41': ["reserved","reserved"],
     922'42': ["reserved","reserved"],
     923'43': ["reserved","reserved"],
     924'44': ["reserved","reserved"],
     925'45': ["reserved","reserved"],
     926'46': ["reserved","reserved"],
     927'47': ["reserved","reserved"],
     928'48': ["reserved","reserved"],
     929'49': ["reserved","reserved"],
     930'50': ["reserved","reserved"],
     931'51': ["reserved","reserved"],
     932'52': ["reserved","reserved"],
     933'53': ["reserved","reserved"],
     934'54': ["reserved","reserved"],
     935'55': ["reserved","reserved"],
     936'56': ["reserved","reserved"],
     937'57': ["reserved","reserved"],
     938'58': ["reserved","reserved"],
     939'59': ["reserved","reserved"],
     940'60': ["reserved","reserved"],
     941'61': ["reserved","reserved"],
     942'62': ["reserved","reserved"],
     943'63': ["reserved","reserved"],
     944'64': ["reserved","reserved"],
     945'65': ["reserved","reserved"],
     946'66': ["reserved","reserved"],
     947'67': ["reserved","reserved"],
     948'68': ["reserved","reserved"],
     949'69': ["reserved","reserved"],
     950'70': ["reserved","reserved"],
     951'71': ["reserved","reserved"],
     952'72': ["reserved","reserved"],
     953'73': ["reserved","reserved"],
     954'74': ["reserved","reserved"],
     955'75': ["reserved","reserved"],
     956'76': ["reserved","reserved"],
     957'77': ["reserved","reserved"],
     958'78': ["reserved","reserved"],
     959'79': ["reserved","reserved"],
     960'80': ["reserved","reserved"],
     961'81': ["reserved","reserved"],
     962'82': ["reserved","reserved"],
     963'83': ["reserved","reserved"],
     964'84': ["reserved","reserved"],
     965'85': ["reserved","reserved"],
     966'86': ["reserved","reserved"],
     967'87': ["reserved","reserved"],
     968'88': ["reserved","reserved"],
     969'89': ["reserved","reserved"],
     970'90': ["reserved","reserved"],
     971'91': ["reserved","reserved"],
     972'92': ["reserved","reserved"],
     973'93': ["reserved","reserved"],
     974'94': ["reserved","reserved"],
     975'95': ["reserved","reserved"],
     976'96': ["reserved","reserved"],
     977'97': ["reserved","reserved"],
     978'98': ["reserved","reserved"],
     979'99': ["reserved","reserved"],
     980'100': ["%g mb","%g-%g mb"],
     981'101': ["mean sea level","reserved"],
     982'102': ["%g m above mean sea level","%g-%g m above mean sea level"],
     983'103': ["%g m above ground","%g-%g m above ground"],
     984'104': ["%g sigma level","%g-%g sigma layer"],
     985'105': ["%g hybrid level","%g-%g hybrid layer"],
     986'106': ["%g m underground","%g-%g m underground"],
     987'107': ["%g K isentropic level","%g-%g K isentropic layer"],
     988'108': ["%g mb above ground","%g-%g mb above ground"],
     989'109': ["PV=%g (Km^2/kg/s) surface","reserved"],
     990'110': ["reserved","reserved"],
     991'111': ["%g Eta level","%g-%g Eta layer"],
     992'112': ["reserved","reserved"],
     993'113': ["%g logarithmic hybrid level","reserved"],
     994'114': ["snow level","reserved"],
     995'115': ["%g sigma height level","%g-%g sigma heigh layer"],
     996'116': ["reserved","reserved"],
     997'117': ["mixed layer depth","reserved"],
     998'118': ["%g hybrid height level","%g-%g hybrid height layer"],
     999'119': ["%g hybrid pressure level","%g-%g hybrid pressure layer"],
    1000'120': ["reserved","reserved"],
    1001'121': ["reserved","reserved"],
    1002'122': ["reserved","reserved"],
    1003'123': ["reserved","reserved"],
    1004'124': ["reserved","reserved"],
    1005'125': ["reserved","reserved"],
    1006'126': ["reserved","reserved"],
    1007'127': ["reserved","reserved"],
    1008'128': ["reserved","reserved"],
    1009'129': ["reserved","reserved"],
    1010'130': ["reserved","reserved"],
    1011'131': ["reserved","reserved"],
    1012'132': ["reserved","reserved"],
    1013'133': ["reserved","reserved"],
    1014'134': ["reserved","reserved"],
    1015'135': ["reserved","reserved"],
    1016'136': ["reserved","reserved"],
    1017'137': ["reserved","reserved"],
    1018'138': ["reserved","reserved"],
    1019'139': ["reserved","reserved"],
    1020'140': ["reserved","reserved"],
    1021'141': ["reserved","reserved"],
    1022'142': ["reserved","reserved"],
    1023'143': ["reserved","reserved"],
    1024'144': ["reserved","reserved"],
    1025'145': ["reserved","reserved"],
    1026'146': ["reserved","reserved"],
    1027'147': ["reserved","reserved"],
    1028'148': ["reserved","reserved"],
    1029'149': ["reserved","reserved"],
    1030'150': ["%g generalized vertical height coordinate","reserved"],
    1031'151': ["soil level %g","reserved"],
    1032'152': ["reserved","reserved"],
    1033'153': ["reserved","reserved"],
    1034'154': ["reserved","reserved"],
    1035'155': ["reserved","reserved"],
    1036'156': ["reserved","reserved"],
    1037'157': ["reserved","reserved"],
    1038'158': ["reserved","reserved"],
    1039'159': ["reserved","reserved"],
    1040'160': ["%g m below sea level","%g-%g m below sea level"],
    1041'161': ["%g m below water surface","%g-%g m ocean layer"],
    1042'162': ["lake or river bottom","reserved"],
    1043'163': ["bottom of sediment layer","reserved"],
    1044'164': ["bottom of thermally active sediment layer","reserved"],
    1045'165': ["bottom of sediment layer penetrated by thermal wave","reserved"],
    1046'166': ["maxing layer","reserved"],
    1047'167': ["bottom of root zone","reserved"],
    1048'168': ["reserved","reserved"],
    1049'169': ["reserved","reserved"],
    1050'170': ["reserved","reserved"],
    1051'171': ["reserved","reserved"],
    1052'172': ["reserved","reserved"],
    1053'173': ["reserved","reserved"],
    1054'174': ["top surface of ice on sea, lake or river","reserved"],
    1055'175': ["top surface of ice, und snow on sea, lake or river","reserved"],
    1056'176': ["bottom surface ice on sea, lake or river","reserved"],
    1057'177': ["deep soil","reserved"],
    1058'178': ["reserved","reserved"],
    1059'179': ["top surface of glacier ice and inland ice","reserved"],
    1060'180': ["deep inland or glacier ice","reserved"],
    1061'181': ["grid tile land fraction as a model surface","reserved"],
    1062'182': ["grid tile water fraction as a model surface","reserved"],
    1063'183': ["grid tile ice fraction on sea, lake or river as a model surface","reserved"],
    1064'184': ["grid tile glacier ice and inland ice fraction as a model surface","reserved"],
    1065'185': ["reserved","reserved"],
    1066'186': ["reserved","reserved"],
    1067'187': ["reserved","reserved"],
    1068'188': ["reserved","reserved"],
    1069'189': ["reserved","reserved"],
    1070'190': ["reserved","reserved"],
    1071'191': ["reserved","reserved"],
    1072'192': ["reserved","reserved"],
    1073'193': ["reserved","reserved"],
    1074'194': ["reserved","reserved"],
    1075'195': ["reserved","reserved"],
    1076'196': ["reserved","reserved"],
    1077'197': ["reserved","reserved"],
    1078'198': ["reserved","reserved"],
    1079'199': ["reserved","reserved"],
    1080'200': ["entire atmosphere (considered as a single layer)","reserved"],
    1081'201': ["entire ocean (considered as a single layer)","reserved"],
    1082'202': ["reserved","reserved"],
    1083'203': ["reserved","reserved"],
    1084'204': ["highest tropospheric freezing level","reserved"],
    1085'205': ["reserved","reserved"],
    1086'206': ["grid scale cloud bottom level","reserved"],
    1087'207': ["grid scale cloud top level","reserved"],
    1088'208': ["reserved","reserved"],
    1089'209': ["boundary layer cloud bottom level","reserved"],
    1090'210': ["boundary layer cloud top level","reserved"],
    1091'211': ["boundary layer cloud layer","reserved"],
    1092'212': ["low cloud bottom level","reserved"],
    1093'213': ["low cloud top level","reserved"],
    1094'214': ["low cloud layer","reserved"],
    1095'215': ["cloud ceiling","reserved"],
    1096'216': ["reserved","reserved"],
    1097'217': ["reserved","reserved"],
    1098'218': ["reserved","reserved"],
    1099'219': ["reserved","reserved"],
    1100'220': ["planetary boundary layer","reserved"],
    1101'221': ["layer between two hybrid levels","reserved"],
    1102'222': ["middle cloud bottom level","reserved"],
    1103'223': ["middle cloud top level","reserved"],
    1104'224': ["middle cloud layer","reserved"],
    1105'225': ["reserved","reserved"],
    1106'226': ["reserved","reserved"],
    1107'227': ["reserved","reserved"],
    1108'228': ["reserved","reserved"],
    1109'229': ["reserved","reserved"],
    1110'230': ["reserved","reserved"],
    1111'231': ["reserved","reserved"],
    1112'232': ["high cloud bottom level","reserved"],
    1113'233': ["high cloud top level","reserved"],
    1114'234': ["high cloud layer","reserved"],
    1115'235': ["%gC ocean isotherm","%g-%gC ocean isotherm layer"],
    1116'236': ["layer between two depths below ocean surface","%g-%g m ocean layer"],
    1117'237': ["bottom of ocean mixed layer","reserved"],
    1118'238': ["bottom of ocean isothermal layer","reserved"],
    1119'239': ["layer ocean surface and 26C ocean isothermal level","reserved"],
    1120'240': ["ocean mixed layer","reserved"],
    1121'241': ["%g in sequence","reserved"],
    1122'242': ["convective cloud bottom level","reserved"],
    1123'243': ["convective cloud top level","reserved"],
    1124'244': ["convective cloud layer","reserved"],
    1125'245': ["lowest level of the wet bulb zero","reserved"],
    1126'246': ["maximum equivalent potential temperature level","reserved"],
    1127'247': ["equilibrium level","reserved"],
    1128'248': ["shallow convective cloud bottom level","reserved"],
    1129'249': ["shallow convective cloud top level","reserved"],
    1130'250': ["reserved","reserved"],
    1131'251': ["deep convective cloud bottom level","reserved"],
    1132'252': ["deep convective cloud top level","reserved"],
    1133'253': ["lowest bottom level of supercooled liquid water layer","reserved"],
    1134'254': ["highest top level of supercooled liquid water layer","reserved"],
    1135'255': ["missing","reserved"],
    1136}